---
hide:
  - navigation
  - toc
---

# Swap Anything Docs

<div class="grid" markdown>
<img alt="swap-anything-logo" src="./static/founderswap-logo.jpg">
<div markdown>
# Welcome to Swap Anything!

A mix and match (swap) library to empower swapping-based projects.

[![Docs](https://github.com/founderswap/swap-anything/actions/workflows/build_docs.yaml/badge.svg)](https://founderswap.github.io/swap-anything/)
[![Tests](https://github.com/founderswap/swap-anything/actions/workflows/test.yaml/badge.svg)](https://github.com/founderswap/swap-anything/actions/workflows/test.yaml)
[![codecov](https://codecov.io/gh/founderswap/swap-anything/graph/badge.svg?token=QF6L5Y8EPM)](https://codecov.io/gh/founderswap/swap-anything)
[![PyPI version](https://badge.fury.io/py/swap-anything.svg)](https://badge.fury.io/py/swap-anything)

NOTE: `swapanything` is still in its early steps. If you want to
contribute or sponsor this project, visit
[www.founderswap.xyz](https://www.founderswap.xyz)

</div>
</div>
